@@ -6,13 +6,14 @@ from datetime import datetime
 from time import time
 from functools import lru_cache
 from json.decoder import JSONDecodeError
-from typing import Any, Callable, Dict, Iterable, Iterator, List, Optional
+from typing import Any, Callable, Dict, Iterable, Iterator, List, Optional, Union, cast
 
 import requests
 import structlog
 from structlog.stdlib import LoggerFactory
 from tenacity import retry, retry_if_exception_type, stop_after_attempt, wait_exponential
 
+from evergreen.alias import VariantAlias
 from evergreen.build import Build
 from evergreen.commitqueue import CommitQueue
 from evergreen.config import (
@@ -158,7 +159,9 @@ class EvergreenApi(object):
 
         response.raise_for_status()
 
-    def _paginate(self, url: str, params: Dict = None) -> Dict:
+    def _paginate(
+        self, url: str, params: Dict = None
+    ) -> Union[List[Dict[str, Any]], Dict[str, Any]]:
         """
         Paginate until all results are returned and return a list of all JSON results.
 
@@ -290,6 +293,25 @@ class EvergreenApi(object):
 
         return version_list.json()  # type: ignore[arg-type]
 
+    def alias_for_version(
+        self, version_id: str, alias: str, include_deps: bool = False
+    ) -> List[VariantAlias]:
+        """
+        Get the tasks and variants that an alias would select for an evergreen version.
+
+        :param version_id: Evergreen version to query against.
+        :param alias: Alias to query.
+        :param include_deps: If true, will also select tasks that are dependencies.
+        :return: List of Variant alias details.
+        """
+        params = {"version": version_id, "alias": alias, "include_deps": include_deps}
+        url = self._create_url("/projects/test_alias")
+        variant_alias_list = self._paginate(url, params)
+        return [
+            VariantAlias(cast(Dict[str, Any], variant_alias), self)
+            for variant_alias in variant_alias_list
+        ]
+
     def versions_by_project(
         self, project_id: str, requester: Requester = Requester.GITTER_REQUEST
     ) -> Iterator[Version]:
@@ -663,6 +685,31 @@ class EvergreenApi(object):
         )
         return [PerformanceData(result, self) for result in self._paginate(url)]  # type: ignore[arg-type]
 
+    def json_by_task(self, task_id: str, json_key: str) -> Dict[str, Any]:
+        """
+        Get the json reported for task {task_id} using the key {json_key}.
+
+        :param task_id: Id of task to query for.
+        :param json_key: The key that json was published under, e.g. "perf".
+        :return: The json published for that task.
+        """
+        url = self._create_plugin_url(f"/task/{task_id}/{json_key}")
+        return cast(Dict[str, Any], self._paginate(url))
+
+    def json_history_for_task(
+        self, task_id: str, task_name: str, json_key: str
+    ) -> List[Dict[str, Any]]:
+        """
+        Get the history of json reported for task {task_id} using the key {json_key}.
+
+        :param task_id: Id of task to query for.
+        :param task_name: Name of task to query for.
+        :param json_key: The key that json was published under, e.g. "perf".
+        :return: A chronological list of json published for that task.
+        """
+        url = f"{self._api_server}/api/2/task/{task_id}/json/history/{task_name}/{json_key}"
+        return cast(List[Dict[str, Any]], self._paginate(url))
+
     def _create_old_url(self, endpoint: str) -> str:
         """
         Build a url for an pre-v2 endpoint.
